===============================
 Gnocchi - Metric as a Service
===============================

.. image:: https://travis-ci.org/gnocchixyz/gnocchi.png?branch=master
    :target: https://travis-ci.org/gnocchixyz/gnocchi
    :alt: Build Status

.. image:: https://badge.fury.io/py/gnocchi.svg
    :target: https://badge.fury.io/py/gnocchi

.. image:: doc/source/_static/gnocchi-logo.png

Gnocchi is an open-source, multi-tenant timeseries, metrics and resources
database. It provides an `HTTP REST`_ interface to create and manipulate the
data. It is designed to store metrics at a very large scale while providing
access to metrics and resources information and history.

You can read the full documentation online at http://gnocchi.xyz.

.. _`HTTP REST`: https://en.wikipedia.org/wiki/Representational_state_transfer
